C-----------------------------------------------------------------------
C     Routines for creating the HTML file of results.
C     This file should present the results in a much similar way as the
C     PostScript output.
C     Design is based on adjoining to each PostScript calls
C     (in sfch_graph_1.f) a parallel call for generating the
C     corresponding description under HTML
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C
C SUBROUTINE INITHTML  -  Initialize the HTML file
C
C-----------------------------------------------------------------------

      SUBROUTINE INITHTML (IERR)

      INCLUDE 'sfch_graph.inc'
      INCLUDE 'sfch_version.fh'
      INCLUDE 'sfch_html.inc'

      INTEGER IERR

      IF (.NOT.HTMLF) RETURN

C  --- Open and Initialize the HTML file
      CALL HTMLOPEN (FILHTML,CODE_NDB,IERR)

      END

C-----------------------------------------------------------------------
C HTMLOPEN - Open the HTML file and write header part
C-----------------------------------------------------------------------
      SUBROUTINE HTMLOPEN (FNAME,CODE,IERR)

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      CHARACTER*(*) FNAME
      CHARACTER*(*) CODE
      INTEGER IERR, MDOC

      IF (.NOT.HTMLF) RETURN

C---- Open output file
      IERR=0
      OPEN(UNIT=UNHTML, FILE=FNAME, STATUS='UNKNOWN',
     -     FORM='FORMATTED', ACCESS='SEQUENTIAL',
     -     ERR=900)

      WRITE(UNHTML,'(A)') '<HTML>'
      WRITE(UNHTML,'(A)') '<HEAD>'
      WRITE(UNHTML,'(A,A,A)') '<TITLE>SFCHECK for ',CODE,'</TITLE>'
      WRITE(UNHTML,'(A)') '</HEAD>'
      WRITE(UNHTML,'(A)') '<BODY>'
      WRITE(UNHTML,'(A)') '<CENTER>'
      WRITE(UNHTML,'(A)') '<H1>Structure Factor Check</H1>'
      WRITE(UNHTML,'(A,A,A)') '<H1>',CODE,'</H1>'
      WRITE(UNHTML,'(A)') '</CENTER>'

      GO TO 999

C---- Errors on parameter file
 900  CONTINUE
      MDOC=0
      CALL MSGERR(MDOC,'WARNING: Unable to open the HTML file')
      IERR=1
      GO TO 999

 999  CONTINUE
      RETURN
      END

C-----------------------------------------------------------------------
C HTMLCLOSE - Write out end of HTML file, and close it
C-----------------------------------------------------------------------
      SUBROUTINE HTMLCLOSE

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'
      
      IF (.NOT.HTMLF) RETURN

      WRITE(UNHTML,'(A)') '</BODY>'
      WRITE(UNHTML,'(A)') '</HTML>'

      CLOSE(UNHTML)

      RETURN
      END

C-----------------------------------------------------------------------
C
C SUBROUTINE STARTHTMLRESULTS
C
C-----------------------------------------------------------------------
      SUBROUTINE STARTHTMLRESULTS

      INCLUDE 'sfch_graph.inc'
      INCLUDE 'sfch_html.inc'
      INTEGER IERR

      IF (.NOT.HTMLF) RETURN
      CALL HTMLTEXT ('<P>')
      CALL HTMLURL (FILREHTML,'SFCHECK Summary Results')
      CALL HTMLTEXT ('<P>')
      CALL HTMLURL (FILPLHTML,'SFCHECK Plots')
      CALL HTMLTEXT ('<P>SFCHECK Local Estimation')
      CALL HTMLINDENT
      CALL HTMLURL (FILLOHTML,'Plots')
      CALL HTMLTEXT ('<BR>')
      CALL HTMLURL ('../cgi-bin/LocEstSelTool.cgi?'//CODE_NDB,
     +     'Visualization of Local Estimator with Rasmol')
      CALL HTMLUNINDENT
C      CALL HTMLTEXT ('<P>')
C      CALL HTMLURL (FILLOHTML,'SFCHECK Local Estimation')
C      CALL HTMLTEXT ('<BR>')
C      CALL HTMLURL ('../cgi-bin/LocEstSelTool.cgi?'//CODE_NDB,
C     +     'Visualization of Local Estimator with Rasmol')
      CALL HTMLCLOSE
      
      CALL HTMLOPEN (FILREHTML,CODE_NDB,IERR)

      END

C-----------------------------------------------------------------------
C HTMLCENTER - Center what follows
C-----------------------------------------------------------------------
      SUBROUTINE HTMLCENTER

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      IF (.NOT.HTMLF) RETURN

      WRITE(UNHTML,'(A)') '<CENTER>'

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLECENTER - End centering
C-----------------------------------------------------------------------
      SUBROUTINE HTMLECENTER

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      IF (.NOT.HTMLF) RETURN

      WRITE(UNHTML,'(A)') '</CENTER>'

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLH2 - Write a H2 string
C-----------------------------------------------------------------------
      SUBROUTINE HTMLH2(STRING)

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      CHARACTER*(*) STRING
      INTEGER TS, TE

      IF (.NOT.HTMLF) RETURN

      CALL TRIM(STRING,TS,TE)
      WRITE(UNHTML,'(A,A,A)') '<H2>',STRING(TS:TE),'</H2>'

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLH3 - Write a H3 string
C-----------------------------------------------------------------------
      SUBROUTINE HTMLH3(STRING)

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      CHARACTER*(*) STRING
      INTEGER TS, TE

      IF (.NOT.HTMLF) RETURN

      CALL TRIM(STRING,TS,TE)
      WRITE(UNHTML,'(A,A,A)') '<H3>',STRING(TS:TE),'</H3>'

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLH4 - Write a H4 string
C-----------------------------------------------------------------------
      SUBROUTINE HTMLH4(STRING)

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      CHARACTER*(*) STRING
      INTEGER TS, TE

      IF (.NOT.HTMLF) RETURN

      CALL TRIM(STRING,TS,TE)
      WRITE(UNHTML,'(A,A,A)') '<H4>',STRING(TS:TE),'</H4>'

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLINDENT - Indent to the right
C-----------------------------------------------------------------------
      SUBROUTINE HTMLINDENT

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      IF (.NOT.HTMLF) RETURN

      WRITE(UNHTML,'(A)') '<UL>'

      RETURN
      END


C-----------------------------------------------------------------------
C HTMLUNINDENT - End of right indentation
C-----------------------------------------------------------------------
      SUBROUTINE HTMLUNINDENT

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      IF (.NOT.HTMLF) RETURN

      WRITE(UNHTML,'(A)') '</UL>'

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLTEXT - Just writes text to the HTML file
C-----------------------------------------------------------------------
      SUBROUTINE HTMLTEXT (STRING)

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      CHARACTER*(*) STRING
      INTEGER TS, TE

      IF (.NOT.HTMLF) RETURN

      CALL TRIM(STRING,TS,TE)
      WRITE(UNHTML,'(A)') STRING(TS:TE)

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLNLTEXT - Just writes text to the HTML file to a newline
C-----------------------------------------------------------------------
      SUBROUTINE HTMLNLTEXT (STRING)

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      CHARACTER*(*) STRING
      INTEGER TS, TE

      IF (.NOT.HTMLF) RETURN

      CALL TRIM(STRING,TS,TE)
      WRITE(UNHTML,'(A,A)') '<BR>', STRING(TS:TE)

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLTABLE - Beginning of a HTML table
C-----------------------------------------------------------------------
      SUBROUTINE HTMLTABLE (BORDERFLAG)

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      LOGICAL BORDERFLAG

      IF (.NOT.HTMLF) RETURN

      IF (BORDERFLAG) THEN
         WRITE(UNHTML,'(A)') '<TABLE BORDER>'
      ELSE
         WRITE(UNHTML,'(A)') '<TABLE>'
      ENDIF
      RETURN
      END

C-----------------------------------------------------------------------
C HTMLETABLE - End of a HTML table
C-----------------------------------------------------------------------
      SUBROUTINE HTMLETABLE

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      IF (.NOT.HTMLF) RETURN

      WRITE(UNHTML,'(A)') '</TABLE>'

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLROW2T - Write a table row of 2 cells
C-----------------------------------------------------------------------
      SUBROUTINE HTMLROW2T (STRING1,STRING2)

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      CHARACTER*(*) STRING1, STRING2
      INTEGER TS, TE, US, UE

      IF (.NOT.HTMLF) RETURN

      CALL TRIM(STRING1,TS,TE)
      CALL TRIM(STRING2,US,UE)
      WRITE(UNHTML,'(A,A,A,A)') '<TR VALIGN=top><TD>',STRING1(TS:TE),
     1     '<TD>',STRING2(US:UE)

      RETURN
      END

C-----------------------------------------------------------------------
C HTML2COL
C-----------------------------------------------------------------------
      SUBROUTINE HTML2COL (STRING)

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      CHARACTER*(*) STRING
      INTEGER TS, TE

      IF (.NOT.HTMLF) RETURN

      CALL TRIM(STRING,TS,TE)
      WRITE(UNHTML,'(A,A)') '<TR VALIGN=top><TD COLSPAN=2>',
     +     STRING(TS:TE)

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLROW - Start a row of an HTML table (of any size)
C-----------------------------------------------------------------------
      SUBROUTINE HTMLROW

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      IF (.NOT.HTMLF) RETURN

      WRITE(UNHTML,'(A)') '<TR VALIGN=top>'

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLCELL - Fill (start) a cell of an HTML table
C-----------------------------------------------------------------------
      SUBROUTINE HTMLCELL (STRING)

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      CHARACTER*(*) STRING
      INTEGER TS, TE

      IF (.NOT.HTMLF) RETURN

      CALL TRIM(STRING,TS,TE)
      WRITE(UNHTML,'(A,A)') '<TD>', STRING(TS:TE)

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLURL - Write a table row of 2 cells
C-----------------------------------------------------------------------
      SUBROUTINE HTMLURL (LOCATION,STRING)

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      CHARACTER*(*) LOCATION, STRING
      INTEGER TS, TE, US, UE

      IF (.NOT.HTMLF) RETURN

      CALL TRIM(LOCATION,TS,TE)
      CALL TRIM(STRING,US,UE)
      WRITE(UNHTML,'(A,A,A,A,A)') '<A HREF="',LOCATION(TS:TE),
     1     '">',STRING(US:UE),'</A>'

      RETURN
      END

C-----------------------------------------------------------------------
C 
C-----------------------------------------------------------------------
      SUBROUTINE HTML

      IMPLICIT NONE
      
      INCLUDE 'sfch_html.inc'

      IF (.NOT.HTMLF) RETURN

      RETURN
      END

C-----------------------------------------------------------------------
C HTMLITAL - Make the text italic
C-----------------------------------------------------------------------
      CHARACTER*(*) FUNCTION HTMLITAL (STRING)

      IMPLICIT NONE

      CHARACTER*(*) STRING
      INTEGER TS, TE, FREELEN

      CALL TRIM(STRING,TS,TE)
      FREELEN = LEN(HTMLITAL) - (TE-TS+1)
      IF (FREELEN.GE.7) THEN
         HTMLITAL = '<I>'//STRING(TS:TE)//'</I>'
      ELSE
         HTMLITAL = '<I>'//STRING(TS:(TE-(7-FREELEN)))//'</I>'
      ENDIF

      RETURN
      END
